@@ -660,6 +660,7 @@ sub union {
     }
 
     my @tmp;
+    my $is_real = !$a1->tolerance && !$b1->tolerance;
     B: foreach $ib ($ib .. $#{$b_list}) {
         foreach $ia ($ia .. $#{$a1->{list}}) {
             @tmp = _simple_union($a1->{list}[$ia], $b_list->[$ib], $a1->{tolerance});
@@ -669,7 +670,8 @@ sub union {
                     while (1) {
                         last if $ia >= $#{$a1->{list}};    
                         last unless _simple_intersects ( $a1->{list}[$ia], $a1->{list}[$ia + 1] )
-                            || $a1->{list}[$ia]{b} == $a1->{list}[$ia + 1]{a};
+                            ||    $is_real 
+                               && $a1->{list}[$ia]{b} == $a1->{list}[$ia + 1]{a};
                         @tmp = _simple_union($a1->{list}[$ia], $a1->{list}[$ia + 1], $a1->{tolerance});
                         last unless @tmp == 1;
                         $a1->{list}[$ia] = $tmp[0];
@@ -781,7 +783,7 @@ sub universal_set {
 
 *difference = \&complement;
 
-sub simmetric_difference {
+sub symmetric_difference {
     my $a1 = shift;
     my $b1;
     if (ref ($_[0]) eq ref($a1) ) {
@@ -795,6 +797,8 @@ sub simmetric_difference {
            $b1->complement( $a1 ) );
 }
 
+*simmetric_difference = \&symmetric_difference; # bugfix
+
 sub min { 
     ($_[0]->min_a)[0];
 }
@@ -1147,7 +1151,7 @@ The I<infinity> value is generated by Perl, when it finds a numerical overflow:
 
 =head1 AUTHOR
 
-    Flavio Soibelmann Glock <fglock@pucrs.br>
+    Flavio S. Glock <fglock@gmail.com>
 
 =cut
 
